#       Makefile.h file for cluster.astro.univie.ac.at
#
#       FLASH makefile definitions for Linux (Intel compiler)


#----------------------------------------------------------------------------
# Set the HDF/HDF5 library paths -- these need to be updated for your system
#----------------------------------------------------------------------------


HDF5path = /opt/sw/hdf5/1.8.10-p1
MPIpath  = /opt/intel/impi/4.1.0.024/intel64

PAPI_PATH  = 
PAPI_FLAGS = 

ZLIB_PATH  = 

NCMPI_PATH =

MPE_PATH   =

# only used for Multispecies Unit
#MA28_PATH  = /home/lv70129/barnold/FLASH3.2/lib/ma28/

#----------------------------------------------------------------------------
# Compiler and linker commands
#
#  We use the f90 compiler as the linker, so some C libraries may explicitly
#  need to be added into the link line.
#----------------------------------------------------------------------------

FCOMP      = $(MPIpath)/bin/mpiifort -shared-intel -mcmodel=large -traceback
CCOMP	   = $(MPIpath)/bin/mpiicc -traceback
CPPCOMP    = $(MPIpath)/bin/mpiicc
LINK	   = $(MPIpath)/bin/mpiifort -shared-intel -mcmodel=large -traceback


# pre-processor flag

PP         = -D

#-----------------------------------------------------------------------------
# Compilation flags
#
#  Three sets of compilation/linking flags are defined: one for optimized code
#  code ("-opt"), one for debugging ("-debug"), and one for testing ("-test").
#  Passing these flags to the setup script will cause the value associated with
#  the corresponding keys (i.e. those ending in "_OPT", "_DEBUG", or "_TEST") to
#  be incorporated into the final Makefile. For example, passing "-opt" to the
#  setup script will cause the flags following "FFLAGS_OPT" to be assigned to
#  "FFLAGS" in the final Makefile. If none of these flags are passed, the default
#  behavior will match that of the "-opt" flag.
#  In general, "-opt" is meant to optimize compilation and linking. "-debug"
#  should enable runtime bounds checking, debugger symbols, and other compiler-
#  specific debugging options. "-test" is useful for testing different
#  combinations of compiler flags particular to your individual system.
#----------------------------------------------------------------------------

FFLAGS_OPT   = -c -r8 -i4 -O1 -real_size 64 #for ifort compiler without optimization
FFLAGS_DEBUG = -c -r8 -i4 -O1 -real_size 64 -g -traceback -check #for ifort compiler  

FFLAGS_PAPI  = -I$(PAPI_PATH)/include

F90FLAGS     =

#CFLAGS       = -c -O2 -tpp7 -march=pentium4 -mcpu=pentium4 -ip -unroll \
#               -D_LARGEFILE64_SOURCE

CFLAGS_OPT =   -I$(MPIpath)/include -c -O1 -D_LARGEFILE64_SOURCE -g
CFLAGS_DEBUG = -I$(MPIpath)/include -c -g 
CFLAGS_TEST  = -I$(MPIpath)/include -c
CFLAGS_HDF5  = -I$(HDF5path)/include -DH5_USE_16_API
CFLAGS_NCMPI = -I$(NCMPI_PATH)/include
#----------------------------------------------------------------------------
# Linker flags
#
#  There is a seperate version of the linker flags for each of the _OPT, 
#  _DEBUG, and _TEST cases.
#----------------------------------------------------------------------------

LFLAGS       =  -o

#----------------------------------------------------------------------------
# Library specific linking
#
#  If a FLASH module has a 'LIBRARY xxx' line in its Config file, we need to
#  create a macro in this Makefile.h for LIB_xxx, which will be added to the
#  link line when FLASH is built.  This allows us to switch between different
#  (incompatible) libraries.  We also create a _OPT, _DEBUG, and _TEST
#  library macro to add any performance-minded libraries (like fast math),
#  depending on how FLASH was setup.
#----------------------------------------------------------------------------

LIB_MPI     = -L$(MPIpath)/lib -lmpich

LIB_HDF5    = -L$(HDF5path)/lib -lhdf5 -lz -DH5_USE_16_API

# only used for Multispecies Unit
#LIB_MA28    = -L$(MA28_PATH) -lz

LIB_PAPI    = $(PAPI_PATH)/lib/libpapi.a $(PAPI_PATH)/lib/_fixunssfdi.o
LIB_PNG     = -lpng -lz

LIB_OPT     = 
LIB_DEBUG   =
LIB_TEST    =

LIB_NCMPI   = -L$(NCMPI_PATH)/lib -lpnetcdf

LIB_MPE     =
#----------------------------------------------------------------------------
#----------------------------------------------------------------------------
# Additional machine-dependent object files
#
#  Add any machine specific files here -- they will be compiled and linked
#  when FLASH is built.
#----------------------------------------------------------------------------

MACHOBJ = 

#----------------------------------------------------------------------------
# Additional commands
#---------------------------------------------------------------------------- 

MV    = mv -f
AR    = ar -r
RM    = rm -f
CD    = cd
RL    = ranlib
ECHO  = echo

